//
//  ViewController.swift
//  TestApp
//
//  Created by Anton D. on 6/25/15.
//  Copyright © 2021 MindFusion. All rights reserved.
//

import UIKit
import Diagramming

class ViewController: UIViewController {

    override func viewDidLoad()
    {
        super.viewDidLoad()
        initDiagram(diagram: diagramView.diagram)
    }
    
    func initDiagram(diagram: Diagram)
    {
        diagram.shapeNodeStyle.brush =
            LinearGradientBrush(color1: Colors.LightGray, color2: Colors.DarkTurquoise, angle: 30)
        diagram.allowSelfLoops = false
        diagram.routeLinks = true
        diagram.showAnchors = ShowAnchors.always
        
        diagram.linkCreated +=
        {
                sender, args in
                args.link.shape = LinkShape.cascading
        }
        
        let pattern1 = AnchorPattern(points: [
            AnchorPoint(x: 50, y: 0, allowIncoming: true, allowOutgoing: true),
            AnchorPoint(x: 100, y: 50, allowIncoming: true, allowOutgoing: true),
            AnchorPoint(x: 50, y: 100, allowIncoming: true, allowOutgoing: true),
            AnchorPoint(x: 0, y: 50, allowIncoming: true, allowOutgoing: true)
            ])
        
        let pattern2 = AnchorPattern(points: [
            AnchorPoint(x: 10, y: 0, allowIncoming: true, allowOutgoing: false, markStyle: MarkStyle.circle, color: Colors.RoyalBlue),
            AnchorPoint(x: 50, y: 0, allowIncoming: true, allowOutgoing: false, markStyle: MarkStyle.circle, color: Colors.Blue),
            AnchorPoint(x: 90, y: 0, allowIncoming: true, allowOutgoing: false, markStyle: MarkStyle.circle, color: Colors.Firebrick),
            AnchorPoint(x: 10, y: 100, allowIncoming: false, allowOutgoing: true, markStyle: MarkStyle.rectangle),
            AnchorPoint(x: 50, y: 100, allowIncoming: false, allowOutgoing: true, markStyle: MarkStyle.rectangle),
            AnchorPoint(x: 90, y: 100, allowIncoming: false, allowOutgoing: true, markStyle: MarkStyle.rectangle),
            AnchorPoint(x: 0, y: 50, allowIncoming: true, allowOutgoing: true, markStyle: MarkStyle.custom)
            ])
        
        let node1 = ShapeNode()
        node1.bounds = Rect(x: 10, y: 15, width: 25, height: 18)
        node1.shape = Shape.fromId(id: "Ellipse")
        node1.text = "Start"
        node1.anchorPattern = pattern1
        diagram.addItem(node1)
        
        let node2 = ShapeNode()
        node2.bounds = Rect(x: 20, y: 85, width: 25, height: 18)
        node2.text = "node 1"
        node2.anchorPattern = pattern2
        diagram.addItem(node2)
        
        let node3 = ShapeNode()
        node3.bounds = Rect(x: 70, y: 80, width: 25, height: 18)
        node3.text = "node 2"
        node3.anchorPattern = pattern2
        diagram.addItem(node3)
        
        let node4 = ShapeNode()
        node4.bounds = Rect(x: 80, y: 110, width: 25, height: 18)
        node4.shape = Shape.fromId(id: "Ellipse")
        node4.text = "End";
        node4.anchorPattern = pattern1
        diagram.addItem(node4)
        
        let decision1 = ShapeNode()
        decision1.bounds = Rect(x: 20, y: 45, width: 30, height: 20)
        decision1.shape = Shape.fromId(id: "Decision")
        decision1.text = "check 1"
        decision1.anchorPattern = AnchorPattern.decision1In3Out
        diagram.addItem(decision1)
        
        let decision2 = ShapeNode()
        decision2.bounds = Rect(x: 70, y: 40, width: 30, height: 20)
        decision2.shape = Shape.fromId(id: "Decision")
        decision2.text = "check 2"
        decision2.anchorPattern = AnchorPattern.decision2In2Out
        diagram.addItem(decision2)
        
        let link = diagram.factory.createDiagramLink(
            origin: decision1, destination: decision2)
        link.shape = LinkShape.cascading
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }

    @IBOutlet var diagramView: DiagramView!
}
