//
//  ViewController.swift
//  TestApp
//
//  Created by Anton D. on 6/25/15.
//  Copyright © 2021 MindFusion. All rights reserved.
//

import UIKit
import Diagramming

class ViewController: UIViewController
{
    weak var logNode: TableNode!

    override func viewDidLoad()
    {
        super.viewDidLoad()
        initDiagram(diagram: diagramView.diagram)
    }
    
    func initDiagram(diagram: Diagram)
    {
        logNode = diagram.factory.createTableNode(
            x: 10, y: 10, width: 60, height: 200, columns: 1, rows:0)
        logNode.locked = true
        logNode.brush = SolidColorBrush(color: Colors.LightGray)
        logNode.text = "event log"
        logNode.horizontalTextAlignment = HorizontalAlignment.center
        
        diagram.nodeCreated += { s,e in self.log(message: "node created") }
        diagram.linkCreated += { s,e in self.log(message: "link created") }
        diagram.nodeClicked += { s,e in self.log(message: "node clicked") }
        diagram.linkClicked += { s,e in self.log(message: "link clicked") }
        diagram.nodeModified += { s,e in self.log(message: "node modified") }
        diagram.linkModified += { s,e in self.log(message: "link modified") }
        diagram.nodeDeleted += { s,e in self.log(message: "node deleted") }
        diagram.linkDeleted += { s,e in self.log(message: "link deleted") }
        diagram.contextMenuCreated += { s,e in self.log(message: "context menu") }
    }
    
    func log(message: String)
    {
        logNode.insertRow(0)
        logNode.cells.getItem(0, row: 0)?.text = message
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }

    @IBOutlet var diagramView: DiagramView!
}
