//
//  ViewController.swift
//  TestApp
//
//  Created by Anton D. on 6/25/15.
//  Copyright © 2021 MindFusion. All rights reserved.
//

import UIKit
import Diagramming

class ViewController: UIViewController
{
    var diagram: Diagram!
    let nodeBounds = Rect(x: 0, y: 0, width: 20, height: 20)
    var brushes: [Brush] = []

    override func viewDidLoad()
    {
        super.viewDidLoad()
        diagram = diagramView.diagram
        
        diagramView.behavior = Behavior.pan
        
        // use differect brush for each tree level
        brushes = [
            LinearGradientBrush(color1: Colors.LightSteelBlue, color2: Colors.BlueViolet, angle: 30),
            LinearGradientBrush(color1: Colors.White, color2: Colors.LightBlue, angle: 30),
            LinearGradientBrush(color1: Colors.White, color2: Colors.DeepSkyBlue, angle: 30),
            LinearGradientBrush(color1: Colors.LimeGreen, color2: Colors.Green, angle: 30)
        ]
    }

    @IBAction func onRandomTree(_ sender: Any)
    {
        diagram.clear()
        
        var root = diagram.factory.createShapeNode(bounds: nodeBounds)
        randomTree(node: root, depth: 5, minChildren: 4)
        arrange(root: root)
    }
    
    func arrange(root: DiagramNode)
    {
        var layout = FractalLayout()
        layout.root = root
        diagram.arrange(layout)

        diagram.resizeToFitItems(5)
        diagramView.zoomToRect(diagram.bounds)
    }
    
    func randomTree(node: DiagramNode, depth: Int, minChildren: Int)
    {
        if (depth <= 0)
        {
            return
        }

        var children = Int(arc4random_uniform(UInt32(depth))) - 1 + minChildren
    
        if (diagram.nodes.count < 3 && children < 2)
        {
            children = 2
        }
    
        for var _ in 0..<children
        {
            // create child node and link
            let child = diagram.factory.createShapeNode(bounds: nodeBounds)
            child.brush = brushes[depth % brushes.count]
            diagram.factory.createDiagramLink(origin: node, destination: child)

            // build child branch
            randomTree(node: child, depth: depth - 1, minChildren: minChildren)
        }
    }


    @IBOutlet weak var randomTreeBtn: UIButton!
    @IBOutlet var diagramView: DiagramView!
}
