//
//  ViewController.swift
//  TestApp
//
//  Created by Anton D. on 6/25/15.
//  Copyright © 2021 MindFusion. All rights reserved.
//

import UIKit
import Diagramming

class ViewController: UIViewController {

    override func viewDidLoad()
    {
        super.viewDidLoad()
        initDiagram(diagram: diagramView.diagram)
    }
    
    func initDiagram(diagram: Diagram)
    {
        // create first table
        var table1 = diagram.factory.createTableNode(
            x: 20, y: 20, width: 42, height: 42)
        table1.redimTable(columns: 2, rows: 6)
        table1.columns[1].columnStyle = ColumnStyle.autoWidth
        table1.text = "Table 1"
        table1.brush = SolidColorBrush(color: Colors.LightGray)
        table1.captionBackBrush = SolidColorBrush(color: Colors.Gray)
        table1.fontName = "Arial"
        
        var cell = table1[0, 0]
        cell.columnSpan = 2
        cell.text = "Heading 1"
        cell.horizontalTextAlignment = .center
        cell.brush = SolidColorBrush(color: Colors.LightGray)
        
        cell = table1[0, 3]
        cell.columnSpan = 2
        cell.text = "Heading 2"
        cell.horizontalTextAlignment = .center
        cell.brush = SolidColorBrush(color: Colors.LightGray)
        
        cell = table1[0, 1]
        cell.rowSpan = 2
        cell.image = UIImage(named: "icon1")

        cell = table1[0, 4]
        cell.rowSpan = 2
        cell.image = UIImage(named: "icon2")
        
        for i in 1...4
        {
            var row = i <= 2 ? i : i + 1
            var cell = table1[1, row]
            cell.text = "item " + String(i)
            cell.horizontalTextAlignment = .right
        }
        
        // create second table
        var table2 = diagram.factory.createTableNode(
            x: 120, y: 36, width: 55, height: 30)
        table2.redimTable(columns: 3, rows: 4)
        table2.brush = SolidColorBrush(color: Colors.LightGray)
        table2.captionBackBrush = SolidColorBrush(color: Colors.Black)
        table2.columns[2].columnStyle = .autoWidth
        table2.text = "Table 2"
        table2.textColor = Colors.White
        
        cell = table2[1, 0]
        cell.rowSpan = 3
        cell.columnSpan = 2
        cell.image = UIImage(named: "icon3")
        
        for i in 0...3
        {
            var cell = table2[0, i]
            cell.text = "row " + String(i)
            cell.textColor = Colors.Blue
        }
        var colors = [Colors.Red, Colors.Green, Colors.Blue]
        for i in 0...2
        {
            var cell = table2[i, 3]
            cell.text = "col " + String(i)
            cell.textColor = Colors.Black
            cell.brush = SolidColorBrush(color: colors[i])
        }
        
        // draw link from "item 1" in first table to "row 0" in second table
        var link = diagram.factory.createDiagramLink(
            origin: table1, originRow: 1, destination: table2, destRow: 0)

    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }

    @IBOutlet var diagramView: DiagramView!
}
