//
//  ViewController.swift
//  TestApp
//
//  Created by Anton D. on 6/25/15.
//  Copyright © 2021 MindFusion. All rights reserved.
//

import UIKit
import Diagramming

class ViewController: UIViewController {

    override func viewDidLoad()
    {
        super.viewDidLoad()
        initDiagram(diagram: diagramView.diagram)
    }
    
    func initDiagram(diagram: Diagram)
    {
        diagram.shapeNodeStyle.brush =
            LinearGradientBrush(color1: Colors.LightGray, color2: Colors.White, angle: 30)
        
        var i = 0
        var size = 20.0
        var perLine = 8
        
        // enum all predefined shapes
        var shapelib = Diagram.defaultShapes!
        var sortedShapes = shapelib.shapes.sorted(by: { $0.0 < $1.0 })
        for (id,shape) in sortedShapes
        {
            // skip some arrowhead shapes that aren't that useful as node shapes
            if (shape?.outline.count == 0) { continue }
            if (id == "RevWithCirc") { continue }
            if (id == "DoubleArrow") { continue }
            if (id == "CenteredCircle") { continue }
            
            // create a node with this shape
            var node = ShapeNode()
            node.shape = shape
            node.stroke = Colors.Black
            node.bounds = Rect(
                x: Double(i % perLine) * (size + 10) + 8.0,
                y: Double(i / perLine) * (size + 20) + 8.0,
                width: size, height: size)
            node.verticalTextAlignment = VerticalAlignment.center
            diagram.addItem(node)
            
            // split longer shape identifiers to display as labels
            var text = id
            if text.count > 10
            {
                let regexp = try! NSRegularExpression(
                    pattern: "([a-z])([A-Z])",
                    options: .allowCommentsAndWhitespace)
                text = regexp.stringByReplacingMatches(
                    in: text, options: NSRegularExpression.MatchingOptions(rawValue: 0),
                    range: NSMakeRange(0, text.count), withTemplate: "$1\n$2")
            }

            // create a label node
            var label = ShapeNode()
            label.text = text
            label.transparent = true
            label.textColor = Colors.Blue
            label.bounds = Rect(
                x: Double(i % perLine) * (size + 10) + 8.0 - 10,
                y: node.bounds.bottom() + 2,
                width: size + 20, height: size)
            label.verticalTextAlignment = VerticalAlignment.top
            diagram.addItem(label)
            
            i = i + 1
        }
        
        diagram.resizeToFitItems(10)
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }

    @IBOutlet var diagramView: DiagramView!
}
