//
//  ViewController.swift
//  TestApp
//
//  Created by Anton D. on 6/25/15.
//  Copyright © 2021 MindFusion. All rights reserved.
//

import UIKit
import Diagramming

class ViewController: UIViewController
{
    override func viewDidLoad()
    {
        super.viewDidLoad()

        //load the graph xml
        let str:String? = Bundle.main.path(forResource: "SampleGraph", ofType:"xml")
        let domBuilder:XmlDomBuilder = XmlDomBuilder()
        domBuilder.parseFile(str!)

        let diagram = diagramView.diagram
        let nodeBounds = Rect(x: 0, y: 0, width: 16, height: 8)
        var map:[String:DiagramNode] = [:]
        
        //load node data
        let xmlElementNodes = domBuilder.root?.getChild("Nodes")?.children
        for xmlNode in xmlElementNodes!
        {
            let node = diagram.factory.createShapeNode(bounds: nodeBounds)
            map[xmlNode.attributes["id"]!] = node
            node.text = xmlNode.attributes["name"]!
        }
        
        //load link data
        let xmlElementLinks = domBuilder.root?.getChild("Links")?.children
        for xmlLink in xmlElementLinks!
        {
            diagram.factory.createDiagramLink(
                origin: map[xmlLink.attributes["origin"]!]!,
                destination: map[xmlLink.attributes["target"]!]!);
        }
        
        //arrange the graph
        let layout = LayeredLayout()
        layout.layerDistance = 16;
        diagram.arrange(layout)
        diagram.labelLayoutInvalid = true

        diagramView.setNeedsDisplay()
    }

    override func didReceiveMemoryWarning()
    {
        super.didReceiveMemoryWarning()
    }

    @IBOutlet var diagramView: DiagramView!
}

