//
//  ViewController.swift
//  TestApp
//
//  Created by Anton D. on 6/25/15.
//  Copyright © 2021 MindFusion. All rights reserved.
//

import UIKit
import Diagramming

class ViewController: UIViewController {

    override func viewDidLoad()
    {
        super.viewDidLoad()
        
        let diagram = diagramView.diagram

        let style = Style()
        style.fontSize = 4
        style.fontName = "Verdana"
        style.fontUnit = MeasureUnit.Millimeter
        diagram.style = style
        
        //load the tree xml
        let str:String? = Bundle.main.path(forResource: "treeTutorial", ofType:"xml")
        let domBuilder:XmlDomBuilder = XmlDomBuilder()
        domBuilder.parseFile(str!)
        
        //load the root and it's children
        let root = diagram.factory.createShapeNode(bounds: bounds)
        root.text = domBuilder.root!.name
        createChildren(root, parentElement: domBuilder.root!)
        
        //arrange the tree
        let layout = TreeLayout()
        layout.nodeDistance = 15
        layout.levelDistance = 15
        layout.linkType = TreeLayoutLinkType.cascading
        layout.direction = LayoutDirection.leftToRight
        layout.multipleGraphsPlacement = MultipleGraphsPlacement.vertical
        diagram.arrange(layout)
        diagram.labelLayoutInvalid = true

        diagramView.setNeedsDisplay()
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }

    var bounds = Rect(x: 0,y: 0,width: 40,height: 8)
    
    //create children and link them recursively
    fileprivate func createChildren(_ parentNode:DiagramNode, parentElement:XmlElement)
    {
        var elements = parentElement.children
        for i in 0 ..< elements.count
        {
            let element = elements[i]
            if(element.name == "Activity")
            {
                let node = diagramView.diagram.factory.createShapeNode(bounds: bounds)
                node.text = element.attributes["Name"]!
                diagramView.diagram.factory.createDiagramLink(
                    origin: parentNode, destination: node);
                createChildren(node, parentElement: element)
            }
        }
    }

    @IBOutlet weak var diagramView: DiagramView!
}
